{% extends "layouts/base.html" %}

{% block title %}
  {{ _("Erreur 404") }}
{% endblock %}

{% block stylesheets %}{% endblock %}

{% block content %}
  <main class="main-content position-relative border-radius-lg">
    <div class="container-fluid py-4">
      <div class="col-12">
        <div class="card card-chart">
          <div class="row">
            <div class="col-md-12">
              <div class="card">
                <div class="card-header">
                  <div class="card-body">
                    <h1><bold>{{ _("Error 404!") }}</bold></h1>
                    {% if not error_message %}
                    <p>{{ _("Looks like that page doesn't exist... Strange...") }}</p>
                    {% else %}
                      <p>{{ error_message }}</p>
                    {% endif %}
                    <img src="{{ config.ASSETS_ROOT }}/error-404.gif" height="250" />
                    <br /><br />
                    <a class="btn bg-gradient-{{ variables["meta"]["color"] }} mb-1 w-30" href="{{ url_for("base_blueprint.index") }}">{{ _("Back to Home") }}</a>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </main>
{% endblock %}

{% block javascripts %}{% endblock %}
