$table-head-spacer-y:         .75rem !default;
$table-head-spacer-x:         1rem !default;
$table-head-font-size:        .65rem !default;
$table-head-font-weight:      $font-weight-bold !default;
$table-head-text-transform:   uppercase !default;
$table-head-letter-spacing:   1px !default;
$table-head-bg:               $gray-100 !default;
$table-head-color:            $gray-600 !default;
$table-action-color:          $gray-500 !default;

$table-body-font-size:        .8125rem !default;

$table-dark-bg:               theme-color("default") !default;
$table-dark-accent-bg:        rgba($white, .05) !default;
$table-dark-hover-bg:         rgba($white, .075) !default;

$table-dark-head-bg:          lighten($dark, 4%) !default;
$table-dark-head-color:       lighten($dark, 35%) !default;
$table-dark-action-color:     lighten($dark, 35%) !default;
