"""
License: Commercial
Copyright (c) 2019 - present AppSeed.us
Copyright (c) 2020 - present Neuro Assassin (https://github.com/Cog-Creators/Red-Dashboard)
"""

__version__ = "1.6.8"
__authors__ = ["AAA3A", "Neuro Assassin"]

from .app import FlaskApp
