$breadcrumb-dark-bg:                $dark !default;
$breadcrumb-dark-color:             $gray-100 !default;
$breadcrumb-dark-hover-color:       $white !default;
$breadcrumb-dark-active-color:      $gray-300 !default;
$breadcrumb-dark-divider-color:     $gray-500 !default;
