
  <aside class="sidenav bg-white navbar navbar-vertical navbar-expand-xs border-0 border-radius-xl my-3 fixed-start ms-4 " id="sidenav-main" style="scrollbar-width: none;">
    <div class="sidenav-header">
      <i class="fas fa-times p-3 cursor-pointer text-secondary opacity-5 position-absolute end-0 top-0 d-none d-xl-none" aria-hidden="true" id="iconSidenav"></i>
      <a class="navbar-brand m-0" href="/">
        <img src="{{ variables["bot"]["avatar"] }}" class="navbar-brand-img border-radius-sm h-100" alt="main_logo">
        <span class="ms-1 font-weight-bold">{{ variables["bot"]["name"] }} {{ _("Dashboard") }}</span>
      </a>
    </div>
    <hr class="horizontal dark mt-0" style="height: 1px;">
    <div class="collapse navbar-collapse w-auto" style="height: 58%;" id="sidenav-collapse-main">
      <ul class="navbar-nav">
        {% for item in variables["sidenav"] %}
          <li class="{{ "active" if item["active"] else "" }}">
            <a class="nav-link{{ " active" if item["active"] else "" }}" href="{{ item["url"] }}"{{ ' target="blank"' if item["is_http"] }}{{ " data-scroll" if not item["active"] else "" }}>
              <div class="icon icon-shape icon-sm border-radius-md text-center me-2 d-flex align-items-center justify-content-center">
                <i class="{{ item["icon"] }} text-primary text-lg opacity-10" style="margin-bottom: 5px;"></i>
              </div>
              <span class="nav-link-text ms-1">{{ item["name"] }}</span>
            </a>
          </li>
        {% endfor %}
      </ul>
    </div>
    <div class="sidenav-footer mx-3">
      <div class="card card-plain shadow-none bg-transparent" id="sidenavCard">
        <img class="w-50 mx-auto" src="{{ config.ASSETS_ROOT }}/icon-documentation.svg" alt="sidenav_illustration">
        <div class="card-body text-center p-3 w-100 pt-0">
          <div class="docs-info">
            <span class="font-weight-bold">{{ _("Need help?") }}</span><br />
            {% if variables["meta"]["support_server"] %}
              <span class="text-xs font-weight-bold">{{ _("Please join our support server!") }}</span>
            {% else %}
              <span class="text-xs font-weight-bold">{{ _("Please check our docs!") }}</span>
            {% endif %}
          </div>
        </div>
      </div>
      {% if variables["meta"]["support_server"] %}
        <a class="btn bg-gradient-{{ variables["meta"]["color"] }} btn-sm w-100 mb-3" href="{{ variables["meta"]["support_server"] }}" type="button">{{ _("Join Support Server") }}</a>
      {% else %}
        <a class="btn bg-gradient-{{ variables["meta"]["color"] }} btn-sm w-100 mb-3" href="{{ url_for("base_blueprint.commands") }}" type="button">{{ _("Documentation") }}</a>
      {% endif %}
    </div>
  </aside>
  