{% extends "layouts/base.html" %}

{% block title %}
  {{ _("Credits") }}
{% endblock %}

{% block stylesheets %}{% endblock %}

{% block content %}
  <main class="main-content position-relative border-radius-lg">
    <div class="container-fluid py-4">
      <div class="col-12">
        <div class="card card-chart">
          <div class="card-header">
            <h1 class="card-category text-gray">{{ _("Credits") }}</h1>
          </div>
          <div class="row">
            <div class="col-md-12">
              <div class="card">
                <div class="card-body">
                  <p>
                    {{ _('The base template for this Dashboard was created by <a href="https://github.com/timcreative/freebies/blob/master/LICENSE.md">MIT License</a>.')|safe }}<br />
                    {{ _('The Dashboard was edited and recoded to work with Red-DiscordBot by <a href="https://github.com/NeuroAssassin">Neuro Assassin#4779</a> and <a href="https://github.com/AAA3A-AAA3A">AAA3A</a>, licensed under <a href="https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/LICENSE">Affero General Public License v3.0</a>.')|safe }}<br />
                    {{ _('An important part of internal Python RPC logic was coded by <a href="https://github.com/NeuroAssassin">Neuro Assassin#4779</a>, licensed under <a href="https://github.com/Cog-Creators/Red-Dashboard/blob/master/LICENSE">Affero General Public License v3.0</a>.')|safe }}<br />
                    {{ _('This Dashboard was made for <a href="https://github.com/Cog-Creators/Red-DiscordBot">Red Discord Bot</a>, a multifunctional, fully modular Discord bot, created by Twentysix, made great by many. Red Discord Bot is licensed under <a href="https://github.com/Cog-Creators/Red-DiscordBot/blob/V3/develop/LICENSE">GNU General Public License v3.0</a>.')|safe }}
                  </p>
                  <br />
                  <h6 class="card-category text-gray">{{ _('Policies and Disclaimers') }}</h6>
                  <ul>
                    <li>
                      {{ _("Privacy Policy:") }} <a href="https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/documents/Privacy%20Policy.md">https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/documents/Privacy%20Policy.md</a>
                    </li>
                    <li>
                      {{ _("Cookie Policy:") }} <a href="https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/documents/Cookie%20Policy.md">https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/documents/Cookie%20Policy.md</a>
                    </li>
                    <li>
                      {{ _("Third Parties Disclaimer:") }} <a href="https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/documents/Third%20Parties%20Disclaimer.md">https://github.com/AAA3A-AAA3A/Red-Dashboard/blob/main/documents/Third%20Parties%20Disclaimer.md</a>
                    </li>
                  </ul>
                  <sup>{{ _("The above policies and disclaimers only apply on unmodified distributions of Red-Dashboard. Copyright holder makes no guarantee that the documents are accurate on public distributions of Red-Dashboard.") }}</sup>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </main>
{% endblock %}

{% block javascripts %}{% endblock %}
